/* Event Study with Companion Portfolios                                          */
/*  For WRDS PC SAS Remote Submit Method                                          */
/*                                                                                */
/* Eventus for Windows users: This is not the correct code for you. Please look   */
/*   for My Documents\Eventus\Sample Programs and Data (default name; omit My in  */
/*   Vista), which should have been created when Eventus was installed on your    */
/*   PC. Eventus for Windows versions of of this and other example code files are */
/*   in the folder.                                                               */
/*                                                                                */
/* Illustrates the following features:                                            */
/*                                                                                */
/* New in Eventus 8.0:                                                            */
/* MyCompanionIdx and Port1DS to point to user-supplied SAS data sets containing  */
/*   companion portfolio returns and portfolio assignments of securities in the   */
/*   main database (CRSP in this case; could be a mini-database in SASNONCRSP     */
/*   mode.)                                                                       */
/* Companion option to select to use the companion portfolios instead of a        */
/*   market-wide index.                                                           */
/*                                                                                */
/* The remaining options are not specific to the use of companion portfolios;     */
/*   however, the MAR option to select the "market adjusted" benchmark inter-     */
/*   acts with the Companion option in that the abnormal returns are companion    */
/*   portfolio adjusted rather than marketwide index adjusted. The CusiPerm       */
/*   option specifies that the request file contains CUSIPs rather than PERMNOs.  */
/*   The NoMM option suppresses the market model benchmark; omitting the option   */
/*   allows two sets of results to be generated, using market adjusted and market */
/*   model benchmarks (both with the security- and date-matched companion port-   */
/*   folio return substituted for the market return in this program.)             */
/*   The OutWin option specifies a SAS data set to receive the event-by-event     */
/*   results for the windows listed on the Windows statement.                     */
/*                                                                                */
/*   Sample output is available in Event Study with Companion Portfolios.lst.     */

/* Define shortcuts to the text request file and to the data folder on the PC.    */
/* ***** Please change PCFolder to the full path of the folder on your *****      */
/* ***** computer that contains the unzipped example files.            *****      */ 
/* ***** Example: C:\Documents and Settings\Me\My Documents\whatever   *****      */
filename pcreqst 'PCFolder\Request1.dat';
libname evdata 'PCFolder';
/* Most users do not need to change anything below here to run the example.       */

/* Sign on to WRDS */
options nomautosource noimplmac; run;
%let wrds = wrds.wharton.upenn.edu 4016;
options comamid=TCP remote=WRDS;
signon username=_prompt_;
/* (user responds to the user name/password popup) */

/* Begin server statements */
rsubmit;
options ps=50;

/* Define shortcut to request file on WRDS Unix server.  */
/* ~/ means use my home directory.                       */
/* File name need not be same on both systems.           */
/* Make WRDS shortcut be request as expected by Eventus. */
filename request '~/Eventus-Demo-Request1.txt';   
proc upload infile=pcreqst outfile=request; run;

/* Make WRDS copies of the companion portfolio data sets from the PC. */
/* The copies are temporary in this code unless you have a library    */
/* name evdata defined every time SAS starts in your WRDS account. To */
/* make the copies persistent, insert a libname evdata ...; statement */
/* above (but below rsubmit). Replace ... by a quoted directory name. */
proc upload data=evdata.myports;
run;
proc upload data=evdata.mycmpreturns;
run;

/* Run the companion-portfolio event study. */
Eventus Monthly MyCompanionIdx=work.mycmpreturns Port1DS=work.myports;
 Request CusiPerm Companion;
 windows (-12,-1) (-6,-1) (-1,0) (0,+1) (0,0) (1,6);
 Evtstudy Mar NoMM OutWin=work.outwin;

/* Download the CARs data set to PC SAS */
proc download data=work.outwin out=work.outwin;
run;

/* Display the CARs data set in the Output window of PC SAS */
proc print label data=outwin;
 id Request_File_CUSIP;
run;

/* Sign off WRDS */        
endrsubmit;
signoff;

/* End of sample code file */
